@@ -5,6 +5,7 @@ discover passwords in each.
 
 from .. import backend
 from ..util import properties
+from . import fail
 
 
 class ChainerBackend(backend.KeyringBackend):
@@ -21,9 +22,11 @@ class ChainerBackend(backend.KeyringBackend):
     @classmethod
     def priority(cls):
         """
-        High-priority if there are backends to chain, otherwise 0.
+        If there are backends to chain, high priority
+        Otherwise very low priority since our operation when empty
+        is the same as null.
         """
-        return 10 * (len(cls.backends) > 1)
+        return 10 if len(cls.backends) > 1 else (fail.Keyring.priority - 1)
 
     @properties.ClassProperty
     @classmethod
@@ -34,8 +37,7 @@ class ChainerBackend(backend.KeyringBackend):
         allowed = (
             keyring
             for keyring in filter(backend._limit, backend.get_all_keyring())
-            if not isinstance(keyring, ChainerBackend)
-            and keyring.priority > 0
+            if not isinstance(keyring, ChainerBackend) and keyring.priority > 0
         )
         return sorted(allowed, key=backend.by_priority, reverse=True)
 
